--[[ 		     SLDataText Module: Coords 				]]
--[[ Author: Taffu  RevDate: 08/21/2018  Version: 8.0.2 ]]

-- Updated by Elegant
-- Re-added coordinates module using new 8.0 API.

local addon, ns = ...
local SLDT, MODNAME, L = SLDataText, "Coords", ns.L
if ( SLDT ) then SLDT.Coords = CreateFrame("Frame") end
local db, frame, text, tool
local uiMapID

local function GetBestMap()
	uiMapID = C_Map.GetBestMapForUnit("player")
end

function SLDT.Coords:Enable()
	if ( db.enabled ) then
		SLDT:UpdateBaseText(self, db)
		self:RegisterEvent("ZONE_CHANGED")
		self:RegisterEvent("ZONE_CHANGED_INDOORS")
		self:RegisterEvent("ZONE_CHANGED_NEW_AREA")
		self:SetScript("OnEvent", function() GetBestMap() end)
		self:SetScript("OnUpdate", function(_, elapsed)
			self:Refresh()
		end)
		GetBestMap()
	end
	self:Refresh()
end

function SLDT.Coords:Disable()
	if ( not db.enabled ) then
		self:UnregisterEvent("ZONE_CHANGED")
		self:UnregisterEvent("ZONE_CHANGED_INDOORS")
		self:UnregisterEvent("ZONE_CHANGED_NEW_AREA")
		self:SetScript("OnEvent", nil)
		self:SetScript("OnUpdate", nil)
	end
	self:Refresh()
end

function SLDT.Coords:Refresh()
	if ( db.enabled or SLDataText.db.profile.configMode ) then
		if ( not self.firstRun ) then self.firstRun = true; SLDT:UpdateBaseText(self, db) end
		
		local position = C_Map.GetPlayerMapPosition(uiMapID, "player")
		if position and not ( position.x == 0 and position.y == 0 ) then
			if ( frame:IsShown() == nil ) then frame:Show() end
		
			text:SetFormattedText("%."..db.precision.."f, %."..db.precision.."f", position.x*100, position.y*100)
		
			SLDT:UpdateBaseFrame(self, db)
		else
			frame:Hide()
		end
	else
		if ( frame:IsShown() and not SLDataText.db.profile.configMode ) then frame:Hide() end
	end
end

SLDT.Coords.optsTbl = {
	[1] = { [1] = "toggle", [2] = L["Enabled"], [3] = "enabled" },
	[2] = { [1] = "toggle", [2] = L["Global Font"], [3] = "gfont" },
	[3] = { [1] = "toggle", [2] = L["Outline"], [3] = "outline" },
	[4] = { [1] = "toggle", [2] = L["Force Shown"], [3] = "forceShow" },
	[5] = { [1] = "range", [2] = L["Precision"], [3] = "precision", [4] = 0, [5] = 2, [6] = 1 },
	[6] = { [1] = "range", [2] = L["Font Size"], [3] = "fontSize", [4] = 6, [5] = 40, [6] = 1 },
	[7] = { [1] = "select", [2] = L["Font"], [3] = "font", [4] = SLDT.fontTbl },
	[8] = { [1] = "select", [2] = L["Justify"], [3] = "aP", [4] = SLDT.justTbl },
	[9] = { [1] = "text", [2] = L["Parent"], [3] = "anch" },
	[10] = { [1] = "select", [2] = L["Anchor"], [3] = "aF", [4] = SLDT.anchTbl },
	[11] = { [1] = "text", [2] = L["X Offset"], [3] = "xOff" },
	[12] = { [1] = "text", [2] = L["Y Offset"], [3] = "yOff" },
	[13] = { [1] = "select", [2] = L["Frame Strata"], [3] = "strata", [4] = SLDT.stratTbl },
}

local function OnInit()
	SLDT.Coords.db = SLDT.db:RegisterNamespace(MODNAME)
    SLDT.Coords.db:RegisterDefaults({
        profile = {
			name = "Coords",
			enabled = true,
			precision = 0,
			forceShow = true,
			aP = "CENTER",
			anch = "Minimap",
			aF = "BOTTOM",
			xOff = 0,
			yOff = 16,
			strata = "LOW",
			gfont = false,
			fontSize = 12,
			font = "Arial Narrow",
			outline = false,
			tooltipOn = false,
        },
    })
	db = SLDT.Coords.db.profile
	
	SLDT:AddModule(MODNAME, db)
	frame, text, tool = SLDT:SetupBaseFrame(SLDT.Coords)
	
	SLDT.Coords:UnregisterEvent("PLAYER_ENTERING_WORLD")
	SLDT.Coords:Enable()
end

if ( IsAddOnLoaded("SLDataText") ) then
	SLDT.Coords:RegisterEvent("PLAYER_ENTERING_WORLD")
	SLDT.Coords:SetScript("OnEvent", OnInit)
end